### Exported Functions List

#### Created by using DLL Export Viewer

Function Name | Address | Relative Address | Ordinal | Filename | Full Path | Type
--- | --- | --- | --- | --- | --- | ---
public: virtual void __cdecl JournalFilterStreamBase::XBrowser(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d4950 | 0x002d4950 | 6126 (0x17ee) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::WidgetEvent(class AString,class AString) __ptr64 | 0x00000001802d4870 | 0x002d4870 | 6105 (0x17d9) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Wheel(unsigned int,unsigned int,int,int) __ptr64 | 0x00000001802d47e0 | 0x002d47e0 | 6104 (0x17d8) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::TreeCtrl(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d4670 | 0x002d4670 | 6031 (0x178f) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::TabCtrl(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d4500 | 0x002d4500 | 6020 (0x1784) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::SystemBrowser(class AString,class AString,unsigned int) __ptr64 | 0x00000001802d4410 | 0x002d4410 | 6018 (0x1782) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::SliderCtrl(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d42a0 | 0x002d42a0 | 5975 (0x1757) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Size(unsigned int,int,int) __ptr64 | 0x00000001802d4210 | 0x002d4210 | 5969 (0x1751) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Scroll(unsigned int,unsigned int,int,int) __ptr64 | 0x00000001802d4180 | 0x002d4180 | 5676 (0x162c) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::SBTrayAction(class AString,class AString) __ptr64 | 0x00000001802d40a0 | 0x002d40a0 | 5670 (0x1626) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::SBRest(class AString) __ptr64 | 0x00000001802d3fd0 | 0x002d3fd0 | 5669 (0x1625) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::SBMotion(class AString,double,double,double,double,double,double) __ptr64 | 0x00000001802d3e80 | 0x002d3e80 | 5668 (0x1624) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::SBButtonUp(class AString,class AString) __ptr64 | 0x00000001802d3da0 | 0x002d3da0 | 5667 (0x1623) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::SBButtonDown(class AString,class AString) __ptr64 | 0x00000001802d3cc0 | 0x002d3cc0 | 5666 (0x1622) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::RibbonEvent(class AString) __ptr64 | 0x00000001802d3bf0 | 0x002d3bf0 | 5659 (0x161b) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Restore(void) __ptr64 | 0x00000001802d3b90 | 0x002d3b90 | 5657 (0x1619) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::RButtonUp(unsigned int,int,int) __ptr64 | 0x00000001802d38b0 | 0x002d38b0 | 5603 (0x15e3) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::RButtonDown(unsigned int,int,int) __ptr64 | 0x00000001802d3820 | 0x002d3820 | 5602 (0x15e2) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::RButtonDblClk(unsigned int,int,int) __ptr64 | 0x00000001802d3790 | 0x002d3790 | 5601 (0x15e1) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::RangeSliderCtrl(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d3a20 | 0x002d3a20 | 5608 (0x15e8) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::RadioButton(class AString,class AString) __ptr64 | 0x00000001802d3940 | 0x002d3940 | 5607 (0x15e7) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::PushButton(class AString,class AString) __ptr64 | 0x00000001802d36b0 | 0x002d36b0 | 5597 (0x15dd) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::PropPageActivate(class AString) __ptr64 | 0x00000001802d3510 | 0x002d3510 | 5595 (0x15db) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::PropertiesPalette(class AString) __ptr64 | 0x00000001802d35e0 | 0x002d35e0 | 5596 (0x15dc) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::PerfCheck(class AString) __ptr64 | 0x00000001802d3440 | 0x002d3440 | 5574 (0x15c6) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::OptionBarKey(unsigned int,class AString,class AString) __ptr64 | 0x00000001802d3350 | 0x002d3350 | 5551 (0x15af) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Navigate(class AString) __ptr64 | 0x00000001802d3280 | 0x002d3280 | 5517 (0x158d) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::MouseMove(unsigned int,int,int) __ptr64 | 0x00000001802d31f0 | 0x002d31f0 | 5516 (0x158c) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Minimize(void) __ptr64 | 0x00000001802d3190 | 0x002d3190 | 5511 (0x1587) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::MButtonUp(unsigned int,int,int) __ptr64 | 0x00000001802d30a0 | 0x002d30a0 | 5486 (0x156e) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::MButtonDown(unsigned int,int,int) __ptr64 | 0x00000001802d3010 | 0x002d3010 | 5485 (0x156d) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::MButtonDblClk(unsigned int,int,int) __ptr64 | 0x00000001802d2f80 | 0x002d2f80 | 5484 (0x156c) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Maximize(void) __ptr64 | 0x00000001802d3130 | 0x002d3130 | 5501 (0x157d) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::ListCtrl(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d2e10 | 0x002d2e10 | 5456 (0x1550) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::ListBox(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d2ca0 | 0x002d2ca0 | 5455 (0x154f) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::LButtonUp(unsigned int,int,int) __ptr64 | 0x00000001802d2c10 | 0x002d2c10 | 5450 (0x154a) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::LButtonDown(unsigned int,int,int) __ptr64 | 0x00000001802d2b80 | 0x002d2b80 | 5449 (0x1549) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::LButtonDblClk(unsigned int,int,int) __ptr64 | 0x00000001802d2af0 | 0x002d2af0 | 5448 (0x1548) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Key(unsigned int,class AString,unsigned int) __ptr64 | 0x00000001802d2a30 | 0x002d2a30 | 5446 (0x1546) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::InfoCenterEvent(class AString,class AString) __ptr64 | 0x00000001802d2950 | 0x002d2950 | 5351 (0x14e7) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::HostedByLinksView(class AString) __ptr64 | 0x00000001802d2880 | 0x002d2880 | 5331 (0x14d3) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::GridRow(class AString,class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d26b0 | 0x002d26b0 | 5324 (0x14cc) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Grid(class AString,class AString,class Arr<class _variant_t> const & __ptr64) __ptr64 | 0x00000001802d25c0 | 0x002d25c0 | 5323 (0x14cb) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::FamilyBrowser(class AString,class AString) __ptr64 | 0x00000001802d24e0 | 0x002d24e0 | 4910 (0x132e) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::FabricationPartBrowser(class AString,class AString) __ptr64 | 0x00000001802d2400 | 0x002d2400 | 4909 (0x132d) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Edit(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d2290 | 0x002d2290 | 4885 (0x1315) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::DynamicCommand(class AString,unsigned int,class AString) __ptr64 | 0x00000001802d21a0 | 0x002d21a0 | 4881 (0x1311) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::DropToView(class AString,class AString,class AString,int,int) __ptr64 | 0x00000001802d2050 | 0x002d2050 | 4874 (0x130a) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::DropFiles(class AString,class AString) __ptr64 | 0x00000001802d1f70 | 0x002d1f70 | 4872 (0x1308) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Directive(class AString,class Arr<class _variant_t> const & __ptr64) __ptr64 | 0x00000001802d1eb0 | 0x002d1eb0 | 4851 (0x12f3) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::DHtmlEvent(class AString,class AString,class AString) __ptr64 | 0x00000001802d1b60 | 0x002d1b60 | 4818 (0x12d2) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::DateTimeCtrl(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d1d40 | 0x002d1d40 | 4825 (0x12d9) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Data(class AString,class Arr<class _variant_t> const & __ptr64) __ptr64 | 0x00000001802d1c80 | 0x002d1c80 | 4824 (0x12d8) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Command(class AString,class AString) __ptr64 | 0x00000001802d1a80 | 0x002d1a80 | 4777 (0x12a9) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::ComboBox(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d1910 | 0x002d1910 | 4776 (0x12a8) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Close(class AString,class AString) __ptr64 | 0x00000001802d1830 | 0x002d1830 | 4769 (0x12a1) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::CheckComboBox(class AString,class AString,class AString,class AString) __ptr64 | 0x00000001802d16c0 | 0x002d16c0 | 4737 (0x1281) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::CheckBox(class AString,class AString,bool) __ptr64 | 0x00000001802d15d0 | 0x002d15d0 | 4736 (0x1280) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Browser(class AString,class AString) __ptr64 | 0x00000001802d14f0 | 0x002d14f0 | 4721 (0x1271) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::AppButtonEvent(bool,class AString) __ptr64 | 0x00000001802d1430 | 0x002d1430 | 4706 (0x1262) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::AddInEvent(class AString,class AString) __ptr64 | 0x00000001802d1350 | 0x002d1350 | 4681 (0x1249) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function
public: virtual void __cdecl JournalFilterStreamBase::Activate(class AString,class AString) __ptr64 | 0x00000001802d1270 | 0x002d1270 | 4676 (0x1244) | Utility.dll | C:\Program Files\Autodesk\Revit 2017\Utility.dll | Exported Function